@@ -162,6 +162,16 @@ QUrl createEventUrl(const QString& calendarID, SendUpdatesPolicy updatePolicy)
     return url;
 }
 
+QUrl importEventUrl(const QString& calendarID, SendUpdatesPolicy updatePolicy)
+{
+    QUrl url(Private::GoogleApisUrl);
+    url.setPath(Private::CalendarBasePath % QLatin1Char('/') % calendarID % QLatin1String("/events") % QLatin1String("/import"));
+    QUrlQuery query(url);
+    query.addQueryItem(sendUpatesQueryParam, sendUpdatesPolicyToString(updatePolicy));
+    url.setQuery(query);
+    return url;
+}
+
 QUrl removeEventUrl(const QString& calendarID, const QString& eventID)
 {
     QUrl url(Private::GoogleApisUrl);
@@ -329,7 +339,7 @@ ObjectPtr Private::JSONToCalendar(const QVariantMap& data)
 
 QByteArray calendarToJSON(const CalendarPtr& calendar)
 {
-    QVariantMap output, entry;
+    QVariantMap entry;
 
     if (!calendar->uid().isEmpty()) {
         entry.insert(idParam, calendar->uid());
@@ -533,12 +543,12 @@ ObjectPtr Private::JSONToEvent(const QVariantMap& data, const QString &timezone)
         KCalendarCore::ICalFormat format;
         if (rec.leftRef(5) == QLatin1String("RRULE")) {
             auto recurrenceRule = std::make_unique<KCalendarCore::RecurrenceRule>();
-            const auto ok = format.fromString(recurrenceRule.get(), rec.mid(6)); Q_UNUSED(ok);
+            const auto ok = format.fromString(recurrenceRule.get(), rec.mid(6)); Q_UNUSED(ok)
             recurrenceRule->setRRule(rec);
             event->recurrence()->addRRule(recurrenceRule.release());
         } else if (rec.leftRef(6) == QLatin1String("EXRULE")) {
             auto recurrenceRule = std::make_unique<KCalendarCore::RecurrenceRule>();
-            const auto ok = format.fromString(recurrenceRule.get(), rec.mid(7)); Q_UNUSED(ok);
+            const auto ok = format.fromString(recurrenceRule.get(), rec.mid(7)); Q_UNUSED(ok)
             recurrenceRule->setRRule(rec);
             event->recurrence()->addExRule(recurrenceRule.release());
         } else if (rec.leftRef(6) == QLatin1String("EXDATE")) {
